# Guide

```{toctree}
:hidden:
:caption: Overview

introduction
tutorial
tutorial1
```

```{toctree}
:hidden:
:caption: "How to"

setup
query-search
validate
bio-registries
schemas
```

```{toctree}
:hidden:
:caption: Other topics

faq
storage
```
